from django.utils.text import Truncator


def truncate_html_words(value, length):
    return Truncator(value).words(length, html=True)


def truncate_words(value, length):
    return Truncator(value).words(length)



from django.conf.urls import *


urlpatterns = patterns(
    "csefemerideak.views",
    url(
        r"^hamarkada-(?P<hamarkada_slug>(\d+))$",
        "hamarkada_index",
        name="csefemerideak_hamarkada_index",
    ),
    url(
        r"^eguna-(?P<hila_slug>(\d+))-(?P<eguna_slug>(\d+))$",
        "eguna_index",
        name="csefemerideak_eguna_index",
    ),
    url(r"^bilaketa$", "search_index", name="csefemerideak_search_index"),
)




from csefemerideak.models import Efemeridea
from django.contrib import admin

from tinymce.widgets import TinyMCE


class EfemerideaAdmin(admin.ModelAdmin):
    """ """
    list_display = ('pk', 'text', 'date', 'has_moretext','is_public',)
    list_display_links = ('pk','text')
    ordering = ('-date',)
    search_fields = ['text','moretext',]
    list_filter = ('is_public',)

    fieldsets = (
        ('Efemeridea', {
            'fields': ('date', 'text', 'is_public',)
        }),
        ('Informazio gehigarria', {
            'fields': ('moretext',),
            'classes': ['collapse',]
        }),
    )


class TinyMCEEfemerideaAdmin(EfemerideaAdmin):
    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name in ('moretext', ):
            return db_field.formfield(widget=TinyMCE(
                attrs={'cols': 80, 'rows': 30},
                mce_attrs={
                    'theme' : "advanced",
                    'mode' : "textareas",
                    'extended_valid_elements' : "iframe[src|width|height|name|align]",
                    'theme_advanced_buttons1' : "formatselect,bold,italic,underline,separator,justifyleft,justifycenter,justifyright, justifyfull,bullist,numlist,undo,redo,link,unlink,image,code,removeformat",
                    'theme_advanced_buttons2' : "",
                    'theme_advanced_buttons3' : "",
                    'theme_advanced_toolbar_location' : "top",
                    'theme_advanced_toolbar_align' : "left",
                    'theme_advanced_resizing' : 'false',
                    },
            ))
        return super(TinyMCEEfemerideaAdmin, self).formfield_for_dbfield(db_field, **kwargs)



 
#admin.site.register(Efemeridea,TinyMCEEfemerideaAdmin)
admin.site.register(Efemeridea,EfemerideaAdmin)



from django.db import models
from django.template.loader import render_to_string
from datetime import datetime
from django.conf import settings
from django.contrib.contenttypes import generic

# from django.db.models.signals import pre_save

from django.core.urlresolvers import reverse

from django.conf import settings
from .utils.text import truncate_words

TITLE_WORDS = getattr(settings, "UZTARRIA_TITLE_WORDS", 10)


class EfemerideaManager(models.Manager):
    """ """

    def gaurkoak(self):
        gaur = datetime.today()
        return Efemeridea.objects.filter(
            eguna=gaur.day, hila=gaur.month, is_public=True
        )

    def egunbatekoak(self, date):
        return Efemeridea.objects.filter(
            eguna=date.day, hila=date.month, is_public=True
        )

    def urtebatekoak(self, urtea):
        return Efemeridea.objects.filter(urtea=urtea, is_public=True)

    def hamarkadabatekoak(self, hamarkada):
        return Efemeridea.objects.filter(hamarkada=hamarkada, is_public=True)


class Efemeridea(models.Model):
    """ """

    text = models.TextField()
    moretext = models.TextField(null=True, blank=True)
    date = models.DateField()

    eguna = models.IntegerField(db_index=True)
    hila = models.IntegerField(db_index=True)
    urtea = models.IntegerField(db_index=True)
    hamarkada = models.IntegerField(db_index=True)

    is_public = models.BooleanField(default=True)

    added = models.DateTimeField(auto_now_add=True)
    modified = models.DateTimeField(auto_now=True)

    objects = models.Manager()
    egunekoak = EfemerideaManager()

    def _get_title(self):
        """ """
        return truncate_words(self.text, TITLE_WORDS * 2)

    title = property(_get_title)

    def has_moretext(self):
        """ """
        return self.moretext and True or False

    has_moretext.boolean = True

    def get_absolute_url(self):
        """ """
        return reverse("csefemerideak_efemeridea", args=[self.pk])

    def __unicode__(self):
        return "%s-%s-%s: %s" % (self.urtea, self.hila, self.eguna, self.text[:100])

    def save(self, *args, **kwargs):
        """ """
        self.urtea = self.date.year
        self.hila = self.date.month
        self.eguna = self.date.day
        self.hamarkada = self.urtea / 10 * 10
        super(Efemeridea, self).save(*args, **kwargs)

    class Meta:
        ordering = ["-date"]
        verbose_name = "Efemeridea"
        verbose_name_plural = "Efemerideak"


"""
def update_fields(sender, instance, *args, **kwargs):
    instance.urtea = instance.date.year
    instance.hila = instance.date.month
    instance.eguna = instance.date.day
    instance.hamarkada = instance.urtea/10*10   

pre_save.connect(update_fields, sender=Efemeridea)
"""



from setuptools import setup, find_packages
import sys, os

version = '0.8'

setup(
    name="csefemerideak",
    version=version,
    description="",
    long_description="""\
""",
    classifiers=[],  # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    keywords="",
    author="",
    author_email="",
    url="",
    license="",
    packages=find_packages(exclude=["ez_setup", "examples", "tests"]),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        # -*- Extra requirements: -*-
        "django>=1.6,<1.9"
    ],
    entry_points="""
      # -*- Entry points: -*-
      """,
)



from django.http import HttpResponseRedirect, HttpResponseNotFound
from django.template import RequestContext
from django.shortcuts import render_to_response
from django.shortcuts import get_list_or_404, get_object_or_404
from csefemerideak.models import Efemeridea

from datetime import date, timedelta
from django.db.models import Min, Max


def _text_to_fulltext_search(t):
    """ """
    return '+%s*' % t.replace(' ','* +')

def _get_archive():
    """ """
    h = {}
    h['hamarkadak'] = []
    efemerideak = Efemeridea.objects.filter(is_public=True).aggregate(Min('date'), Max('date'))
    h_aurrena = efemerideak['date__min'].year/10
    h_azkena = efemerideak['date__max'].year/10
    for hamarkada in range(h_aurrena,h_azkena+1):
        h2 = {}
        h2['hamarkada'] = hamarkada*10
        h2['kopurua'] = Efemeridea.objects.filter(is_public=True,hamarkada=hamarkada*10).count()
        if h2['kopurua']:
            h['hamarkadak'].append(h2)         
    h['egunak'] = []
    #bisiestoa    
    e_aurrena = date(2012,1,1)
    e_azkena = date(2013,1,1) 
    for d in range(0,(e_azkena-e_aurrena).days):
        e = e_aurrena + timedelta(days=d)
        h2 = {}
        h2['eguna'] = e.day
        h2['hila'] = e.month        
        h2['kopurua'] = Efemeridea.objects.filter(is_public=True,hila=e.month,eguna=e.day).count()
        h['egunak'].append(h2)
    return h    

def index(request):
    h = {}
    h['archive'] = _get_archive()
    h['efemerideak'] = Efemeridea.objects.filter(is_public=True).order_by('-date')
    return render_to_response('csefemerideak/index.html', h, context_instance=RequestContext(request))

def eguna_index(request,hila_slug,eguna_slug):
    h = {}
    h['archive'] = _get_archive()
    h['title'] = 'Eguna: %s-%s' % (hila_slug,eguna_slug)
    h['efemerideak'] = Efemeridea.objects.filter(is_public=True,hila=hila_slug,eguna=eguna_slug).order_by('-date')
    return render_to_response('csefemerideak/index_filtered.html', h, context_instance=RequestContext(request))

def hamarkada_index(request,hamarkada_slug):
    h = {}
    h['archive'] = _get_archive()
    h['title'] = 'Hamarkada: %s' % (hamarkada_slug)
    h['efemerideak'] = Efemeridea.objects.filter(is_public=True,hamarkada=hamarkada_slug).order_by('-date')
    return render_to_response('csefemerideak/index_filtered.html', h, context_instance=RequestContext(request))

def search_index(request):
    """ """
    h = {}
    h['archive'] = _get_archive()    
    bilatutakoa = request.GET.get('bilatutakoa','')
    if request.method == 'GET' and bilatutakoa:     
        h['bilatutakoa'] = bilatutakoa  
        t = _text_to_fulltext_search(bilatutakoa)
        h['efemerideak'] = Efemeridea.objects.filter(is_public=True,text__search=t).order_by('-date')  
        h['kopurua'] = len(h['efemerideak'])
        h['bilaketa_egin_da'] = True        
    else:
        h['bilatutakoa'] = ''    
        h['bilaketa_egin_da'] = False        
         
    return render_to_response('csefemerideak/index_searched.html',h,context_instance=RequestContext(request))

    